@@ -27,7 +27,7 @@
 #   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 #   Boston, MA 02111-1307, USA.
 #
-#   $Id: Content.pm,v 1.28 2005/01/03 01:16:51 fredo Exp $
+#   $Id: Content.pm,v 1.29 2005/01/21 10:19:48 fredo Exp $
 #
 #=======================================================================
 
@@ -43,9 +43,11 @@ BEGIN {
     use PDF::API2::Matrix;
     use Math::Trig;
     use Encode;
-    @ISA = qw(PDF::API2::Basic::PDF::Dict);
+    use Compress::Zlib;
 
-    ( $VERSION ) = '$Revision: 1.28 $' =~ /Revision: (\S+)\s/; # $Date: 2005/01/03 01:16:51 $
+    @ISA = qw(PDF::API2::Basic::PDF::Dict);
+    
+    ( $VERSION ) = '$Revision: 1.29 $' =~ /Revision: (\S+)\s/; # $Date: 2005/01/21 10:19:48 $
 
 }
 
@@ -95,6 +97,12 @@ sub outobjdeep {
         $self->{" $k"}=undef;
         delete($self->{" $k"});
     }
+    if($self->{-docompress}==1 && $self->{Filter})
+    {
+        $self->{' stream'}=Compress::Zlib::compress($self->{' stream'});
+        $self->{' nofilt'}=1;
+        delete $self->{-docompress};
+    }
     $self->SUPER::outobjdeep(@_);
 }
 
@@ -172,6 +180,7 @@ sub compress
 {
     my $self=shift @_;
     $self->{'Filter'}=PDFArray(PDFName('FlateDecode'));
+    $self->{-docompress}=1;
     return($self);
 }
 
@@ -736,7 +745,7 @@ sub vline
     return($self);
 }
 
-=item $gfx->curve $x1, $y1, $x2, $y2, $x3, $y3
+=item $gfx->curve $cx1, $cy1, $cx2, $cy2, $x, $y
 
 =cut
 
@@ -765,6 +774,28 @@ sub curve
     return($self);
 }
 
+=item $gfx->spline $cx1, $cy1, $x, $y
+
+=cut
+
+sub spline
+{
+    my $self=shift @_;
+    
+    while(scalar @_ >= 4)
+    {
+        my $cx=shift @_;
+        my $cy=shift @_;
+        my $x=shift @_;
+        my $y=shift @_;
+        my $c1x=(2*$cx+$self->{' x'})/3;
+        my $c1y=(2*$cy+$self->{' y'})/3;
+        my $c2x=(2*$cx+$x)/3;
+        my $c2y=(2*$cy+$y)/3;
+        $self->curve($c1x,$c1y,$c2x,$c2y,$x,$y);
+    }
+}
+
 sub arctocurve 
 {
     my ($a,$b,$alpha,$beta)=@_;
@@ -2002,6 +2033,9 @@ alfred reibenschuh
 =head1 HISTORY
 
     $Log: Content.pm,v $
+    Revision 1.29  2005/01/21 10:19:48  fredo
+    added spline operator
+
     Revision 1.28  2005/01/03 01:16:51  fredo
     fixed textpos tracking in nl method
 
